@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: commands.c,v 1.61 1999/01/05 19:25:14 kalt Exp $";
+static char rcsid[] = "@(#)$Id: commands.c,v 1.62 1999/08/02 21:37:12 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -58,7 +58,8 @@ static struct aliaslist_ *alias = NULL;
  *	-9	"not implemented"
  */
 
-static char		outp[1024], outa[1024];
+static char		outp[1024];
+static u_char		outa[1024];
 
 /* cmd_smart: if the first word in the buffer is not a channel, prepend
  *	      the window default channel name to the buffer.
