@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: counter.c,v 1.3 1998/06/25 18:16:43 kalt Exp $";
+static char rcsid[] = "@(#)$Id: counter.c,v 1.4 1999/08/02 21:37:12 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -114,7 +114,8 @@ counter_check(entry)
 int
 counter_add(ref, string, attributes, pmatch, flags, channel)
   void *ref;
-  char *string, *attributes, *channel;
+  char *string, *channel;
+  char *attributes;
   regmatch_t *pmatch;
   unsigned int *flags;
 {
