@@ -10,7 +10,7 @@
 void	counter_init();
 # if defined(HAVE_REGEXP)
 void	counter_expire(int);
-int	counter_add(void *,char *,char *,regmatch_t *,unsigned int *,char *);
+int	counter_add(void *,char *,u_char *,regmatch_t *,unsigned int *,char *);
 # endif
 
 #endif
