@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: display.c,v 1.54 1999/01/05 16:57:45 kalt Exp $";
+static char rcsid[] = "@(#)$Id: display.c,v 1.56 1999/08/02 21:37:12 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -28,7 +28,8 @@ extern char		space_add(char *, char *);
 extern char		sic_ctcp(char *, char, char *);
 extern void		url_find(char *, char *, char *);
 
-static char		outp[1024], outa[1024];
+static char		outp[1024];
+static u_char		outa[1024];
 static char		*s, *c, *d, *p;
 static int		n;
 /* locals is currently unused */
@@ -56,12 +57,13 @@ static char		nick[10], user[11], host[64];
  */
 static int
 sic_sprintf(buffer, attr, format, channel, flags)
-char	*buffer, *attr, *format, *channel;
+char	*buffer, *format, *channel;
+u_char  *attr;
 unsigned int	*flags;
 {
-  char	*wp = buffer;
-  char	video = 0, vplus = 0, anyattr = 0, checknow = 0, dobeep = 0;
-  int	align;
+  char		*wp = buffer;
+  u_char	video = 0, vplus = 0, anyattr = 0, checknow = 0, dobeep = 0;
+  int		align;
 
   *wp = '\0';
   while (*format)
@@ -119,7 +121,7 @@ unsigned int	*flags;
 	  case 'n':
 	      strcat(buffer, nick);
 	      get_ignore(s, channel, flags);
-	      if (*flags & LOG_HIGHLIGHT)
+	      if (*flags & LOG_HIGHLIGHT && !(video & TERM_STANDOUT))
 		video |= (vplus = TERM_STANDOUT);
 	      break;
 	  case 'N':
@@ -141,7 +143,7 @@ unsigned int	*flags;
 	  case 'o':
 	      strcat(buffer, s);
 	      get_ignore(s, channel, flags);
-	      if (*flags & LOG_HIGHLIGHT)
+	      if (*flags & LOG_HIGHLIGHT && !(video & TERM_STANDOUT))
 		video |= (vplus = TERM_STANDOUT);
 	      break;
 	  case 'R':
@@ -208,6 +210,7 @@ unsigned int	*flags;
 	  if (checknow)
 	    {
 	      char *where = wp, how = 0;
+	      u_char extra;
 	      int len;
 
 	      checknow = 0;
@@ -220,7 +223,22 @@ unsigned int	*flags;
 		  anyattr = 1;
 	      while (*wp != '\0')
 		{
-		  *attr = video;
+		  extra = 0;
+		  /* check for ircii rendering junk */
+		  if (*wp == ctrl('_'))
+		      extra = TERM_EUNDERLINE;
+		  else if (*wp == ctrl('V'))
+		      extra = TERM_ESTANDOUT;
+		  else if (*wp == ctrl('B'))
+		      extra = TERM_EBOLD;
+		  if (extra)
+		    {
+		      video ^= extra;
+		      extra = TERM_EHIDE;
+		      anyattr = 1;
+		    }
+		  /* keywords */
+		  *attr = video | extra;
 		  if (where)
 		    {
 		      if (wp >= where && (wp - where) < len)
@@ -820,7 +838,7 @@ sic_reformat(log)
   free(log->attributes); log->attributes = NULL;
   if (sic_sprintf(outp, outa, fmt_str, log->dest, &(log->flags)))
     {
-      log->attributes = (char *) malloc(log->len+1);
+      log->attributes = (u_char *) malloc(log->len+1);
       bcopy(outa, log->attributes, log->len+1);
     }
   log->formatted = strdup(outp);
