@@ -8,7 +8,7 @@
 #define	_format_h_
 
 extern	char	*default_format_str[];
-extern	int	out_sprintf(char *, char *, char *, char *, char *, char *);
+extern	int	out_sprintf(char *, u_char *, char *, char *, char *, char *);
 extern	char	*sic_split(char *, char *);
 
 #define	F_NUM		0
