@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: input.c,v 1.35 1999/02/26 02:02:26 kalt Exp $";
+static char rcsid[] = "@(#)$Id: input.c,v 1.37 1999/08/02 21:37:12 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -216,7 +216,7 @@ display_input()
 	     inpos - ((CO-10)*(inpos/(CO-10))) + ((inpos>=CO-10) ? 10:0));
 }
 
-int
+void
 sic_getch()
 {
   static char escape = 0, screen = 0, search = 0, quote = 0, replace = 0;
@@ -227,7 +227,7 @@ sic_getch()
   assert(inpos <= inlen);
 
   if (read(0, &ch, 1) != 1)
-      abort(); /* should simply exit? */
+      return;
   
   server = current->via;
   if (quote)
@@ -367,6 +367,20 @@ sic_getch()
 		    }
 		  replace = 0;
 		  break;
+	      case 'H':
+		  if (option(current->custw.zopt_on, Z_NOCOLOR))
+		      unset_option(current->custw.zopt_on, Z_NOCOLOR);
+		  else
+		      set_option(current->custw.zopt_on, Z_NOCOLOR);
+		  sic_redowin(0);
+		  break;
+	      case 'h':
+		  if (option(current->custw.zopt_on, Z_IRCII))
+		      unset_option(current->custw.zopt_on, Z_IRCII);
+		  else
+		      set_option(current->custw.zopt_on, Z_IRCII);
+		  sic_redowin(0);
+		  break;
 	      case ctrl('H'):
 	      case 127:
 		  if (inpos)
@@ -616,5 +630,5 @@ sic_getch()
 
   if (chg)
       display_input();
-  return 1;
+  return;
 }
