@@ -5,5 +5,5 @@
  */
 
 void	display_input();
-int	sic_getch();
+void	sic_getch();
 int	cmd_run(char *);
