@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: option.c,v 1.34 1999/01/05 16:57:45 kalt Exp $";
+static char rcsid[] = "@(#)$Id: option.c,v 1.35 1999/08/02 21:37:13 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -379,10 +379,10 @@ get_keyword(channel, where, attr, flags)
 		  cp = *where + pmatch[0].rm_so;
 #endif
 	      if (best == NULL || cp < best
-		  && (ktmp->kflag & (K_BOLD|K_UNDERLINE|K_STANDOUT)))
+		  && (ktmp->kflag & (K_BOLD|K_UNDERLINE|K_STANDOUT|K_CHIDE)))
 		{
 		  best = cp;
-		  bestv = ktmp->kflag & (K_BOLD|K_UNDERLINE|K_STANDOUT);
+		  bestv = ktmp->kflag & (K_BOLD|K_UNDERLINE|K_STANDOUT|K_CHIDE);
 #if defined(HAVE_REGEXP)
 		  if (ktmp->kflag & K_REGEXP)
 		      len = pmatch[0].rm_eo - pmatch[0].rm_so;
@@ -455,7 +455,8 @@ get_ignore(from, channel, flags)
 int
 get_rewrite(fmt, string, attributes, flags, channel)
   int fmt;
-  char *string, *attributes, *channel;
+  char *string, *channel;
+  u_char *attributes;
   unsigned int *flags;
 {
 #if defined(HAVE_REGEXP)
@@ -495,7 +496,8 @@ get_rewrite(fmt, string, attributes, flags, channel)
 	      if (*rtmp->new)
 		{
 		  char ostr[1024], oattr[1024],
-		       *nfmt = rtmp->new, *nstr = string, *nattr =attributes;
+		       *nfmt = rtmp->new, *nstr = string;
+		  u_char *nattr =attributes;
 		  
 		  strcpy(ostr, string);
 		  bcopy(attributes, oattr, strlen(string)+1);
