@@ -19,7 +19,7 @@ int	get_option(unsigned int, char *);
 int	get_flag(unsigned int, char *, unsigned int);
 int	get_keyword(char *, char **, char *, unsigned int *);	
 void	get_ignore(char *, char *, unsigned int *);
-int	get_rewrite(int, char *, char *, unsigned int *, char *);
+int	get_rewrite(int, char *, u_char *, unsigned int *, char *);
 
 void	customize(unsigned int, char *, int, char **, unsigned int *);
 
