@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: server.c,v 1.64 1999/02/26 02:01:33 kalt Exp $";
+static char rcsid[] = "@(#)$Id: server.c,v 1.65 1999/08/02 21:49:34 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -20,9 +20,10 @@ static char rcsid[] = "@(#)$Id: server.c,v 1.64 1999/02/26 02:01:33 kalt Exp $";
 # include <sys/filio.h>
 #endif
 
-/* BIND 8.x lossage */
-#undef inet_ntoa
-#undef inet_addr
+#ifdef BIND_HATRED
+# undef inet_ntoa
+# undef inet_addr
+#endif
 
 #include "struct.h"
 #include "term.h"
