@@ -43,7 +43,7 @@ int		term_size();
 void		term_end();
 void		term_putchar(unsigned int);
 int		term_puts(char *, int);
-int		term_putes(char *, int, char *);
+int		term_putes(char *, int, u_char *, u_int);
 void		term_flush();
 void		term_scroll(int, int, int);
 void		term_status(char *, int);
@@ -66,5 +66,16 @@ void		term_input(char *, int);
 #define TERM_UNDERLINE	0x01
 #define	TERM_STANDOUT	0x02
 #define	TERM_BOLD	0x04
+#define	TERM_HIDE	0x08
+
+#define	TERM_CLIENT	(TERM_UNDERLINE|TERM_STANDOUT|TERM_BOLD)
+
+#define TERM_EUNDERLINE	0x10
+#define	TERM_ESTANDOUT	0x20
+#define	TERM_EBOLD	0x40
+#define	TERM_EHIDE	0x80
+
+#define	TERM_ECLIENT	(TERM_EUNDERLINE|TERM_ESTANDOUT|TERM_EBOLD)
+
 
 #endif
