@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: window.c,v 1.63 1999/01/08 17:20:00 kalt Exp $";
+static char rcsid[] = "@(#)$Id: window.c,v 1.64 1999/08/02 21:37:13 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -161,7 +161,7 @@ time_t		ts;
   new->len = strlen(str);
   if (attr)
     {
-      new->attributes = (char *) malloc(strlen(str)+1);
+      new->attributes = (u_char *) malloc(strlen(str)+1);
       bcopy(attr, new->attributes, strlen(str)+1);
     }
   
@@ -845,8 +845,16 @@ display_line(lnb, line)
   int lnb;
   struct log_ *line;
 {
+  u_char mask;
+
   assert(lnb >= 0 && lnb <= LNCNT(line));
 
+  mask = TERM_CLIENT; /* should be toggable */
+  if (option(current->custw.zopt_on, Z_IRCII))
+      mask |= TERM_ECLIENT | TERM_EHIDE;
+  if (option(current->custw.zopt_on, Z_NOCOLOR))
+      mask |= TERM_HIDE;
+
   if (!get_flag(line->flags, line->dest, active->fnb))
       term_underline_on(); /* Z_SHOWALL is on */
   if (lnb == 0)
@@ -865,12 +873,13 @@ display_line(lnb, line)
 	  if (line->flags & LOG_IGNORE)
 	      term_underline_off();
 	}
-      term_putes(line->formatted, PLNLEN(line), line->attributes);
+      term_putes(line->formatted, PLNLEN(line), line->attributes, mask);
     }
   else
       term_putes(line->formatted + (lnb-1)*(CO-1) + PLNLEN(line), CO-1,
 		 (line->attributes) ? 
-		 line->attributes + (lnb-1)*(CO-1) + PLNLEN(line) : NULL);
+		 line->attributes + (lnb-1)*(CO-1) + PLNLEN(line) : NULL,
+		 mask);
   if (!get_flag(line->flags, line->dest, active->fnb))
       term_underline_off();
 }
