@@ -7,7 +7,7 @@
 struct channel_	*get_channel(char *);
 
 void		sic_log(unsigned int, time_t, char *, char *, char *, char *,
-			char, char *, char *);
+			char, char *, u_char *);
 void		vsic_log(unsigned int, char *, char, char *, char *,
 			 char, char *, ...);
 void		vsic_slog(unsigned int, char *, ...);
